=== modified file 'NEWS'
--- NEWS	2008-09-24 04:52:40 +0000
+++ NEWS	2008-08-15 16:24:50 +0000
@@ -1,23 +1,6 @@
 What's changed in loggerhead?
 =============================
 
-dev [future]
-
-    - Added --port, --host and --prefix options to serve-branches
-      script. (Martin Albisetti)
-
-    - Fixed broken template for project browsing with start-loggerhead
-      (Martin Albisetti)
-
-    - Added --reload options to restart the application when a python
-      file change. (Guillermo Gonzalez)
-
-    - Added error handling middleware. (Guillermo Gonzalez)
-
-    - Fix bug #243415 ("Tracebacks go to console but not log
-      file"). Also minor improvements to logging in serve-branches and
-      start-loggerhead. (Guillermo Gonzalez)
-
 1.6 [15Aug2008]
 ----------------
 

=== modified file 'README.txt'
--- README.txt	2008-09-06 20:17:56 +0000
+++ README.txt	2008-07-26 17:53:10 +0000
@@ -11,16 +11,10 @@
 GETTING STARTED
 ---------------
 
-Loggerhead depends on 
-1) SimpleTAL for templating.
-   on ubuntu package `sudo apt-get install python-simpletal`
-   or download from http://www.owlfish.com/software/simpleTAL/download.html
-2) Paste for the server. (You need version 1.2 or newer of Paste.) 
-   on ubuntu package `sudo apt-get install python-paste`
-   or use `easy_install Paste`
-3) Paste Deploy  (optional, needed when proxying through Apache)
-   on ubuntu package `sudo apt-get install python-pastedeploy`
-   or use `easy_install PasteDeploy`
+Loggerhead depends on SimpleTAL for templating and Paste for the
+server.  So you need these installed -- on Ubuntu you want the
+'python-simpletal' and 'python-paste' packages installed.  You need
+version 1.2 or newer of Paste.
 
 Then simply run the 'serve-branches' with the branch you want to
 serve on the command line:
@@ -82,7 +76,10 @@
 
 If Paste Deploy is installed, the 'serve-branches' script can be
 run behind a proxy at the root of a site, but if you're running it at
-some path into the site, you'll need to specify is using '--prefix=/some_path'.
+some path into the site, you'll need to add a 'prefix' argument to the
+PrefixMiddleware call in the script.  More flexible configuration
+should be added soon...
+
 
 FILES CHANGED CACHE
 -------------------

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2008-09-24 04:54:18 +0000
+++ loggerhead/apps/branch.py	2008-09-09 03:47:24 +0000
@@ -26,7 +26,7 @@
 class BranchWSGIApp(object):
 
     def __init__(self, branch, friendly_name=None, config={},
-                 graph_cache=None, branch_link=None, is_root=False):
+                 graph_cache=None, branch_link=None):
         self.branch = branch
         self._config = config
         self.friendly_name = friendly_name
@@ -35,7 +35,6 @@
         if graph_cache is None:
             graph_cache = bzrlib.lru_cache.LRUCache()
         self.graph_cache = graph_cache
-        self.is_root = is_root
 
     def get_history(self):
         _history = History(self.branch, self.graph_cache)
@@ -95,6 +94,7 @@
     def app(self, environ, start_response):
         self._url_base = environ['SCRIPT_NAME']
         self._static_url_base = environ.get('loggerhead.static.url')
+        environ['FRIENDLY_NAME'] = self.friendly_name
         if self._static_url_base is None:
             self._static_url_base = self._url_base
         self._environ = environ

=== modified file 'loggerhead/apps/error.py'
--- loggerhead/apps/error.py	2008-09-29 21:35:53 +0000
+++ loggerhead/apps/error.py	2008-09-09 03:47:24 +0000
@@ -15,39 +15,50 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+import sys
+import logging
+from loggerhead.controllers import TemplatedBranchView
 from loggerhead.controllers.error_ui import ErrorUI
-
+  
 class ErrorHandlerApp(object):
-    """Class for WSGI error logging middleware."""
-
-    msg = " %s.%s: %s \n"
+    '''Class for WSGI error logging middleware.'''
+    
+    msg = " %s.%s: %s \n" 
 
     def __init__(self, application, **kwargs):
         self.application = application
-
+        self.log = getattr(application, 'log', None)
+                
     def __call__(self, environ, start_response):
         try:
             return self.application(environ, start_response)
         except:
-            # test if exc_info has been set, in the case that
-            # the error is caused before BranchWSGGIApp middleware
+            # test if exc_info has been set, in the case that 
+            # the error is caused before BranchWSGGIApp middleware 
             if environ.has_key('exc_info') and environ.has_key('branch'):
                 # Log and/or report any application errors
                 return self.handle_error(environ, start_response)
             else:
-                # simply propagate the error, this is logged
+                # simply propagate the error, this is logged 
                 # by paste.httpexceptions.TransLogger middleware
                 raise
 
     def handle_error(self, environ, start_response):
-        """Exception hanlder."""
+        '''Exception hanlder.'''
         self.log_error(environ)
         return errapp(environ, start_response)
-
+        
     def log_error(self, environ):
         exc_type, exc_object, exc_tb = environ['exc_info']
-        logger = environ['branch'].log
-        logger.exception(self.msg, exc_type.__module__,
+        logger = self.log
+        if environ.has_key('branch'):
+            logger = environ['branch'].log   
+        elif environ.has_key('FRIENDLY_NAME'):
+            logger = logging.getLogger('loggerhead.%s' % 
+                environ['FRIENDLY_NAME'])
+        elif logger is None:
+            logger = logging.getLogger('loggerhead')
+        logger.exception(self.msg, exc_type.__module__, 
                               exc_type.__name__, exc_object)
 
 

=== modified file 'loggerhead/apps/filesystem.py'
--- loggerhead/apps/filesystem.py	2008-08-12 23:10:24 +0000
+++ loggerhead/apps/filesystem.py	2008-08-05 05:11:33 +0000
@@ -24,13 +24,10 @@
     def app_for_branch(self, branch):
         if not self.name:
             name = branch.nick
-            is_root = True
         else:
             name = self.name
-            is_root = False
         branch_app = BranchWSGIApp(
-            branch, name, {'cachepath': sql_dir}, self.root.graph_cache,
-            is_root=is_root)
+            branch, name, {'cachepath': sql_dir}, self.root.graph_cache)
         return branch_app.app
 
     def app_for_non_branch(self, environ):

=== modified file 'loggerhead/changecache.py'
--- loggerhead/changecache.py	2008-09-12 04:34:38 +0000
+++ loggerhead/changecache.py	2008-07-31 05:41:42 +0000
@@ -33,10 +33,18 @@
 
 with_lock = util.with_lock('_lock', 'ChangeCache')
 
-try:
+SQLITE_INTERFACE = os.environ.get('SQLITE_INTERFACE', 'sqlite3')
+
+if SQLITE_INTERFACE == 'sqlite3':
     from sqlite3 import dbapi2
-except ImportError:
-    from pysqlite2 import dbapi2
+    _param_marker = '?'
+
+_select_stmt = ("select data from revisiondata where revid = ?"
+                ).replace('?', _param_marker)
+_insert_stmt = ("insert into revisiondata (revid, data) "
+                "values (?, ?)").replace('?', _param_marker)
+
+
 
 
 class FakeShelf(object):
@@ -57,8 +65,7 @@
     def _unserialize(self, data):
         return cPickle.loads(str(data))
     def get(self, revid):
-        self.cursor.execute(
-            "select data from revisiondata where revid = ?", (revid,))
+        self.cursor.execute(_select_stmt, (revid,))
         filechange = self.cursor.fetchone()
         if filechange is None:
             return None
@@ -66,9 +73,7 @@
             return self._unserialize(filechange[0])
     def add(self, revid_obj_pairs):
         for  (r, d) in revid_obj_pairs:
-            self.cursor.execute(
-                "insert into revisiondata (revid, data) values (?, ?)",
-                (r, self._serialize(d)))
+            self.cursor.execute(_insert_stmt, (r, self._serialize(d)))
         self.connection.commit()
 
 

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2008-09-30 02:04:14 +0000
+++ loggerhead/controllers/__init__.py	2008-07-22 00:40:03 +0000
@@ -73,7 +73,6 @@
             args.append(arg)
 
         vals = {
-            'static_url': self._branch.static_url,
             'branch': self._branch,
             'util': util,
             'history': h,

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2008-09-09 22:42:27 +0000
+++ loggerhead/controllers/annotate_ui.py	2008-07-23 21:41:49 +0000
@@ -20,7 +20,7 @@
 import os
 import posixpath
 
-from paste.httpexceptions import HTTPBadRequest, HTTPServerError
+from paste.httpexceptions import HTTPBadRequest
 
 from loggerhead.controllers import TemplatedBranchView
 from loggerhead import util
@@ -62,21 +62,6 @@
             path = h.get_path(revid, file_id)
         filename = os.path.basename(path)
 
-        # Directory Breadcrumbs
-        directory_breadcrumbs = (
-            util.directory_breadcrumbs(
-                self._branch.friendly_name,
-                self._branch.is_root,
-                'files'))
-
-        # Create breadcrumb trail for the path within the branch
-        try:
-            inv = h.get_inventory(revid)
-        except:
-            self.log.exception('Exception fetching changes')
-            raise HTTPServerError('Could not fetch changes')
-        branch_breadcrumbs = util.branch_breadcrumbs(path, inv, 'files')
-
         return {
             'revid': revid,
             'file_id': file_id,
@@ -86,6 +71,4 @@
             'change': h.get_changes([ revid ])[0],
             'contents': list(h.annotate_file(file_id, revid)),
             'fileview_active': True,
-            'directory_breadcrumbs': directory_breadcrumbs,
-            'branch_breadcrumbs': branch_breadcrumbs,
         }

=== modified file 'loggerhead/controllers/changelog_ui.py'
--- loggerhead/controllers/changelog_ui.py	2008-08-16 21:53:52 +0000
+++ loggerhead/controllers/changelog_ui.py	2008-07-22 00:40:03 +0000
@@ -86,13 +86,6 @@
                     all_same_author = False
                     break
 
-        # Directory Breadcrumbs
-        directory_breadcrumbs = (
-            util.directory_breadcrumbs(
-                self._branch.friendly_name,
-                self._branch.is_root,
-                'changes'))
-
         return {
             'branch': self._branch,
             'changes': changes,
@@ -107,5 +100,4 @@
             'search_failed': search_failed,
             'all_same_author': all_same_author,
             'url': self._branch.context_url,
-            'directory_breadcrumbs': directory_breadcrumbs,
         }

=== modified file 'loggerhead/controllers/diff_ui.py'
--- loggerhead/controllers/diff_ui.py	2008-09-29 21:35:13 +0000
+++ loggerhead/controllers/diff_ui.py	2008-08-14 02:49:52 +0000
@@ -19,27 +19,42 @@
 from cStringIO import StringIO
 import logging
 import time
+import sys
 
+from paste import httpexceptions
 from paste.request import path_info_pop
 
+from loggerhead import history
+from loggerhead import util
+from loggerhead.templatefunctions import templatefunctions
+
+import bzrlib
+from bzrlib import branch
 from bzrlib.diff import show_diff_trees
 
 
 log = logging.getLogger("loggerhead.controllers")
 
 class DiffUI(object):
-    """Class to output a diff for a single file or revisions."""
+    """
 
+    Class to output a diff for a single file or revisions.
+    """
+    
     def __init__(self, branch, history):
         self._branch = branch
         self._history = history
         self.log = history.log
 
+    
     def __call__(self, environ, start_response):
         # /diff/<rev_id>/<rev_id>
-        """Default method called from /diff URL."""
+        """
+        Default method called from /diff URL.
+        """
+
         z = time.time()
-
+        
         args = []
         while 1:
             arg = path_info_pop(environ)
@@ -55,20 +70,20 @@
         if len(args) is 2:
             revid_to = self._history.fix_revid(args[1])
         else:
-            revid_to = change.parents[0].revid
+            revid_to = change.parents[0].revid 
 
 
         repo = self._branch.branch.repository
         revtree1 = repo.revision_tree(revid_from)
         revtree2 = repo.revision_tree(revid_to)
-
+        
         diff_content_stream = StringIO()
-        show_diff_trees(revtree1, revtree2, diff_content_stream,
+        show_diff_trees(revtree1, revtree2, diff_content_stream, 
                         old_label='', new_label='')
 
         content = diff_content_stream.getvalue()
 
-        self.log.info('/diff %r:%r in %r secs' % (revid_from, revid_to,
+        self.log.info('/diff %r:%r in %r secs' % (revid_from, revid_to, 
                                                   time.time() - z))
 
         revno1 = self._history.get_revno(revid_from)

=== modified file 'loggerhead/controllers/directory_ui.py'
--- loggerhead/controllers/directory_ui.py	2008-09-30 02:57:08 +0000
+++ loggerhead/controllers/directory_ui.py	2008-08-06 21:25:24 +0000
@@ -22,7 +22,6 @@
 
 from bzrlib import branch
 
-from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
 
 class DirEntry(object):
@@ -47,9 +46,6 @@
     def __init__(self, static_url_base, path, name):
         class _branch(object):
             context_url = 1
-            @staticmethod
-            def static_url(path):
-                return self._static_url_base + path
         self._branch = _branch
         self._history = None
         self._path = path
@@ -64,6 +60,8 @@
         listing.sort(key=lambda x: x.lower())
         dirs = []
         parity = 0
+        def static_url(path):
+            return self._static_url_base + path
         for d in listing:
             p = os.path.join(self._path, d)
             try:
@@ -72,13 +70,8 @@
                 b = None
             dirs.append(DirEntry(d, parity, b))
             parity = 1 - parity
-        # Create breadcrumb trail
-        directory_breadcrumbs = util.directory_breadcrumbs(
-                self._name,
-                False,
-                'directory')
         return {
             'dirs': dirs,
             'name': self._name,
-            'directory_breadcrumbs': directory_breadcrumbs,
+            'static_url': static_url,
             }

=== modified file 'loggerhead/controllers/error_ui.py'
--- loggerhead/controllers/error_ui.py	2008-09-29 21:32:30 +0000
+++ loggerhead/controllers/error_ui.py	2008-09-09 03:47:24 +0000
@@ -16,11 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-from StringIO import StringIO
-import traceback
-
 from loggerhead.controllers import TemplatedBranchView
-from loggerhead import util
 
 class ErrorUI(TemplatedBranchView):
 
@@ -29,19 +25,11 @@
     def __init__(self, branch, exc_info):
         super(ErrorUI, self).__init__(branch, None)
         self.exc_info = exc_info
-
+    
     def get_values(self, h, args, kw, headers):
         exc_type, exc_object, exc_tb = self.exc_info
-        description = StringIO()
-        traceback.print_exception(exc_type, exc_object, None, file=description)
-        directory_breadcrumbs = (
-            util.directory_breadcrumbs(
-                self._branch.friendly_name,
-                self._branch.is_root,
-                'changes'))
         return {
-            'branch': self._branch,
-            'error_title': 'An unexpected error occurred while proccesing the request:',
-            'error_description': description.getvalue(),
-            'directory_breadcrumbs': directory_breadcrumbs,
-        }
+            'error_title':'Error',
+            'error_description':exc_object,
+            'error_properties':[self.exc_info],
+        }
\ No newline at end of file

=== modified file 'loggerhead/controllers/inventory_ui.py'
--- loggerhead/controllers/inventory_ui.py	2008-08-16 21:53:52 +0000
+++ loggerhead/controllers/inventory_ui.py	2008-07-23 21:41:49 +0000
@@ -75,15 +75,6 @@
         if updir == '/':
             updir_file_id = None
 
-        # Directory Breadcrumbs
-        directory_breadcrumbs = util.directory_breadcrumbs(
-                self._branch.friendly_name,
-                self._branch.is_root,
-                'files')
-
-        # Create breadcrumb trail for the path within the branch
-        branch_breadcrumbs = util.branch_breadcrumbs(path, inv, 'files')
-        
         return {
             'branch': self._branch,
             'util': util,
@@ -100,6 +91,4 @@
             'url': self._branch.context_url,
             'start_revid': start_revid,
             'fileview_active': True,
-            'directory_breadcrumbs': directory_breadcrumbs,
-            'branch_breadcrumbs': branch_breadcrumbs,
         }

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2008-08-16 21:53:52 +0000
+++ loggerhead/controllers/revision_ui.py	2008-07-22 00:40:03 +0000
@@ -72,13 +72,6 @@
         if side_by_side:
             h.add_side_by_side([ change ])
 
-        # Directory Breadcrumbs
-        directory_breadcrumbs = (
-            util.directory_breadcrumbs(
-                self._branch.friendly_name,
-                self._branch.is_root,
-                'changes'))
-
         return {
             'branch': self._branch,
             'revid': revid,
@@ -96,5 +89,4 @@
             'line_count': line_count,
             'line_count_limit': line_count_limit,
             'show_plain_diffs': line_count > line_count_limit,
-            'directory_breadcrumbs': directory_breadcrumbs,
         }

=== modified file 'loggerhead/controllers/search_ui.py'
--- loggerhead/controllers/search_ui.py	2008-09-09 22:42:27 +0000
+++ loggerhead/controllers/search_ui.py	2008-07-26 17:41:49 +0000
@@ -16,13 +16,16 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+from paste.httpexceptions import HTTPServerError
+from loggerhead import history
+from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
 from loggerhead import search
 
 
 class SearchUI(TemplatedBranchView):
     """
-
+    
     Class to output progressive search result terms.
     """
 

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2008-09-27 05:13:24 +0000
+++ loggerhead/history.py	2008-08-12 16:36:23 +0000
@@ -199,7 +199,6 @@
             "Can only construct a History object with a read-locked branch.")
         self._file_change_cache = None
         self._branch = branch
-        self._inventory_cache = {}
         self.log = logging.getLogger('loggerhead.%s' % (branch.nick,))
 
         self.last_revid = branch.last_revision()
@@ -213,7 +212,6 @@
          self._revno_revid, self._merge_sort, self._where_merged
          ) = whole_history_data
 
-
     def use_file_cache(self, cache):
         self._file_change_cache = cache
 
@@ -341,11 +339,8 @@
             return revid
         if revid == 'head:':
             return self.last_revid
-        try:
-            if self.revno_re.match(revid):
-                revid = self._revno_revid[revid]
-        except KeyError:
-            raise bzrlib.errors.NoSuchRevision(self._branch.nick, revid)
+        if self.revno_re.match(revid):
+            revid = self._revno_revid[revid]
         return revid
 
     def get_file_view(self, revid, file_id):
@@ -422,15 +417,12 @@
             return None, None, []
 
     def get_inventory(self, revid):
-        if revid not in self._inventory_cache:
-            self._inventory_cache[revid] = (
-                self._branch.repository.get_revision_inventory(revid))
-        return self._inventory_cache[revid]
+        return self._branch.repository.get_revision_inventory(revid)
 
     def get_path(self, revid, file_id):
         if (file_id is None) or (file_id == ''):
             return ''
-        path = self.get_inventory(revid).id2path(file_id)
+        path = self._branch.repository.get_revision_inventory(revid).id2path(file_id)
         if (len(path) > 0) and not path.startswith('/'):
             path = '/' + path
         return path
@@ -438,7 +430,7 @@
     def get_file_id(self, revid, path):
         if (len(path) > 0) and not path.startswith('/'):
             path = '/' + path
-        return self.get_inventory(revid).path2id(path)
+        return self._branch.repository.get_revision_inventory(revid).path2id(path)
 
     def get_merge_point_list(self, revid):
         """
@@ -567,15 +559,19 @@
         trees = dict((t.get_revision_id(), t) for
                      t in self._branch.repository.revision_trees(required_trees))
         ret = []
-        for revision in revisions:
-            if not revision.parents:
-                old_tree = self._branch.repository.revision_tree(
-                    bzrlib.revision.NULL_REVISION)
-            else:
-                old_tree = trees[revision.parents[0].revid]
-            tree = trees[revision.revid]
-            ret.append(tree.changes_from(old_tree))
-        return ret
+        self._branch.repository.lock_read()
+        try:
+            for revision in revisions:
+                if not revision.parents:
+                    old_tree = self._branch.repository.revision_tree(
+                        bzrlib.revision.NULL_REVISION)
+                else:
+                    old_tree = trees[revision.parents[0].revid]
+                tree = trees[revision.revid]
+                ret.append(tree.changes_from(old_tree))
+            return ret
+        finally:
+            self._branch.repository.unlock()
 
     def _change_from_revision(self, revision):
         """

=== modified file 'loggerhead/search.py'
--- loggerhead/search.py	2008-09-09 22:42:27 +0000
+++ loggerhead/search.py	2008-07-26 17:41:49 +0000
@@ -18,6 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 import sets
+import os
 try:
     from bzrlib.plugins.search import errors
     from bzrlib.plugins.search import index as _mod_index

=== modified file 'loggerhead/static/css/global.css'
--- loggerhead/static/css/global.css	2008-09-09 22:47:45 +0000
+++ loggerhead/static/css/global.css	2008-08-13 17:33:41 +0000
@@ -318,14 +318,4 @@
 }
 #pages a:hover {
 	border:solid 1px #666666;
-}
-.breadcrumb a {
-	color:#889ea9;
-	font-weight:bold;
-	font-size:18px;
-}
-.breadcrumb a:hover{
-	color:#666;
-	font-weight:bold;
-	font-size:18px;
-}
+}		

=== modified file 'loggerhead/templatefunctions.py'
--- loggerhead/templatefunctions.py	2008-09-09 22:47:45 +0000
+++ loggerhead/templatefunctions.py	2008-08-13 19:51:08 +0000
@@ -28,7 +28,6 @@
 
 
 templatefunctions['macros'] = _pt('macros').macros
-templatefunctions['breadcrumbs'] = _pt('breadcrumbs').macros
 
 @templatefunc
 def file_change_summary(url, entry, modified_file_link):

=== modified file 'loggerhead/templates/annotate.pt'
--- loggerhead/templates/annotate.pt	2008-08-16 21:53:52 +0000
+++ loggerhead/templates/annotate.pt	2008-08-04 03:42:01 +0000
@@ -22,9 +22,9 @@
         </a>
       </tal:has-link>
       <tal:no-link condition="not: branch/branch_link">
-        <span metal:use-macro="breadcrumbs/directory"></span>
+        <tal:branch-name replace="branch/friendly_name" />
       </tal:no-link>
-      <span>: <span metal:use-macro="breadcrumbs/branch" /> (revision <tal:revno content="change/revno"></tal:revno>)</span>
+      <span>: <span tal:content="path"></span> (revision <tal:revno content="change/revno"></tal:revno>)</span>
     </h1>
 
     <div metal:fill-slot="content">

=== removed file 'loggerhead/templates/breadcrumbs.pt'
--- loggerhead/templates/breadcrumbs.pt	2008-09-30 02:04:14 +0000
+++ loggerhead/templates/breadcrumbs.pt	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-<html>
-<body>
-<!--
-    Breadcrumbs macros
--->
-<!--
-    These are all defined on one line in order to get the spacing looking right
-    in the output
--->
-
-<!-- Branch breadcrumbs (for the path within the branch) -->
-<span metal:define-macro="branch" class="breadcrumb">
-    <tal:block repeat="crumb branch_breadcrumbs">/<a tal:attributes="href python:url([crumb['suffix'], change.revno], file_id=crumb['file_id'])" tal:content="crumb/dir_name" tal:condition="not:repeat/crumb/end" /><span tal:replace="crumb/dir_name" tal:condition="repeat/crumb/end" /></tal:block>
-</span>
-
-<!-- Directory breadcrumbs (for the path leading up to the branch) -->
-<span metal:define-macro="directory" class="breadcrumb">
-    <tal:block repeat="crumb directory_breadcrumbs"><span tal:condition="not:repeat/crumb/start">/</span><a tal:attributes="href python:static_url('/'+crumb['path'])" tal:content="crumb/dir_name" /></tal:block>
-</span>
-
-</body>
-</html>

=== modified file 'loggerhead/templates/browse.pt'
--- loggerhead/templates/browse.pt	2008-08-20 22:32:48 +0000
+++ loggerhead/templates/browse.pt	2008-07-22 20:07:08 +0000
@@ -1,44 +1,56 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
   <head>
-    <title>loggerhead branches</title>
-    <link rel="stylesheet"
-          tal:attributes="href python:branch.static_url('/static/css/global.css')" />
+    <title metal:fill-slot="title">
+      loggerhead branches
+    </title>
   </head>
 
   <body>
-   <div id="loggerheadCont">
-    <div>
+
+    <h1 metal:fill-slot="heading" style="padding-bottom: 1em">
+      <tal:title condition="title" content="title" />
+      <tal:no-title condition="not:title">
+        bazaar branches in loggerhead
+      </tal:no-title>
+    </h1>
+
+    <div metal:fill-slot="content">
       <div class="browse-project"
            tal:repeat="project projects">
-        <h1 tal:content="project/friendly_name" />
+        <div class="browse-project-name"
+             tal:content="project/friendly_name"></div>
+
         <div class="browse-project-description"
              tal:condition="python:len(project.long_description) > 0"
              tal:content="structure project/long_description"></div>
 
-          <table id="logentries">
-            <tr class="logheader">
-              <th class="summarycell" colspan="2">Name</th>
-              <th class="summarycell">Description</th>
-              <th class="datecell" colspan="2">Last change</th>
+        <div class="browse-view">
+          <table>
+            <tr class="heading">
+              <th>Name</th>
+              <th>Description</th>
+              <th>Last change</th>
+              <th />
             </tr>
             <tal:block repeat="view python:views_by_project[project]">
-              <tr tal:attributes="class string:blueRow1">
-                <td class="icocell">
-                  <img tal:attributes="src python:branch.static_url('/static/images/ico_branch.gif')" />
-                </td>
-                <td class="autcell">
-                    <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name)" 
-                       tal:content="view/friendly_name" />
-                </td>
-                <td class="autcell"
-                    tal:content="view/description" />
-                <td class="date"
-                    tal:content="python:view.get_history().has_revisions and util._approximatedate(view.last_updated()) or '(no revisions)'" />
-                <td class="icocell">
+              <tr>
+                <td class="name">
+                  <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name)"
+                     tal:content="view/friendly_name">
+                    ${view.friendly_name}
+                  </a>
+                </td>
+                <td class="description"
+                    tal:content="view/description">
+                  ${view.description}
+                </td>
+                <td class="last-update"
+                    tal:content="python:view.get_history().has_revisions and util._approximatedate(view.last_updated()) or '(no revisions)'"></td>
+                <td class="feed">
                   <a tal:attributes="href python:branch.static_url(project.name + '/' +  view.name + '/atom')"
                      title="atom feed">
-                    <img tal:attributes="src python:branch.static_url('/static/images/ico_rss.gif')"
+                    <img tal:attributes="src python:branch.static_url('/static/images/feed-icon-16x16.gif')"
                          alt="atom feed" />
                   </a>
                 </td>
@@ -48,13 +60,16 @@
                 </td>
                 <td class="description url" colspan="2">
                   <a tal:attributes="href view/branch_url"
-                     tal:content="view/branch_url" />
+                     tal:content="view/branch_url">
+                    ${view.branch_url}
+                  </a>
                 </td>
               </tr>
             </tal:block>
           </table>
+        </div>
+
       </div>
     </div>
-  </div>
   </body>
 </html>

=== modified file 'loggerhead/templates/changelog.pt'
--- loggerhead/templates/changelog.pt	2008-09-09 22:47:45 +0000
+++ loggerhead/templates/changelog.pt	2008-08-20 20:47:46 +0000
@@ -21,7 +21,7 @@
              </a>
            </tal:has-link>
            <tal:no-link condition="not: branch/branch_link">
-             <span metal:use-macro="breadcrumbs/directory"></span>
+             <tal:branch-name replace="branch/friendly_name" />
            </tal:no-link>
            : changes
           <tal:block condition="filter_file_id">to <span tal:content="python:history.get_path(revid, filter_file_id)" /></tal:block>

=== modified file 'loggerhead/templates/directory.pt'
--- loggerhead/templates/directory.pt	2008-08-16 21:53:52 +0000
+++ loggerhead/templates/directory.pt	2008-08-05 06:12:07 +0000
@@ -7,9 +7,8 @@
   </head>
   <body>
     <div id="loggerheadCont">
-      <h1>
-        Browsing
-        <span metal:use-macro="breadcrumbs/directory" />
+      <h1 tal:content="string:Browsing ${name}">
+        Hi.
       </h1>
 
       <div >

=== modified file 'loggerhead/templates/error.pt'
--- loggerhead/templates/error.pt	2008-09-29 21:32:30 +0000
+++ loggerhead/templates/error.pt	2008-09-09 03:47:24 +0000
@@ -1,30 +1,13 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <tal:block define="onload string:load()">
-  <html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
+  <html xmlns="http://www.w3.org/1999/xhtml">
     <head>
-      <title metal:fill-slot="title"
-             tal:content="string:${branch/friendly_name} : error"></title>
+      <title tal:content="error_title">
+      </title>
     </head>
     <body>
-        <tal:block metal:fill-slot="heading">
-        <h1>
-           <tal:has-link condition="branch/branch_link">
-            <a tal:attributes="href branch/branch_link"
-               tal:content="branch/friendly_name">
-               nice/branch/name
-            </a>
-           </tal:has-link>
-            <tal:no-link condition="not: branch/branch_link">
-                <span metal:use-macro="breadcrumbs/directory"></span>
-            </tal:no-link>
-           : error
-        </h1>
-        <pre>
-            <p tal:content="error_title"/>
-            <p tal:content="error_description"/>
-        </pre>
-        <br/><br/>
-        </tal:block>
+        <p tal:content="error_description"/>
+        <p tal:content="error_properties"/>
     </body>
   </html>
 </tal:block>

=== modified file 'loggerhead/templates/inventory.pt'
--- loggerhead/templates/inventory.pt	2008-08-16 04:57:38 +0000
+++ loggerhead/templates/inventory.pt	2008-08-06 04:20:07 +0000
@@ -17,12 +17,11 @@
           nice/branch/name
         </a>
       </tal:has-link>
-      <span tal:condition="not: branch/branch_link">
-        <span metal:use-macro="breadcrumbs/directory" />
-      </span>
+      <tal:no-link condition="not: branch/branch_link">
+        <tal:branch-name replace="branch/friendly_name" />
+      </tal:no-link>
       : viewing
-      <span metal:use-macro="breadcrumbs/branch" />
-      for revision <span tal:content="change/revno"/>
+      <span tal:content="path" /> for revision <span tal:content="change/revno"/>
     </h1>
 
     <div metal:fill-slot="content">

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2008-09-09 22:47:45 +0000
+++ loggerhead/templates/revision.pt	2008-08-16 06:34:03 +0000
@@ -23,7 +23,7 @@
             </a>
           </tal:has-link>
           <tal:no-link condition="not: branch/branch_link">
-            <span metal:use-macro="breadcrumbs/directory"></span>
+            <tal:branch-name replace="branch/friendly_name" />
           </tal:no-link>
           <span>: <tal:revno content="change/revno"></tal:revno>
         <tal:compare-to condition="python:compare_revid is not None">

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2008-09-12 04:36:13 +0000
+++ loggerhead/tests/test_simple.py	2008-07-01 04:01:31 +0000
@@ -1,4 +1,5 @@
 import cgi
+import unittest
 import os
 import tempfile
 import shutil
@@ -8,6 +9,7 @@
 import bzrlib.osutils
 from configobj import ConfigObj
 
+from loggerhead.history import History
 from loggerhead.apps.branch import BranchWSGIApp
 from paste.fixture import TestApp
 
@@ -50,7 +52,7 @@
     """
 
     def setUpLoggerhead(self):
-        app = TestApp(BranchWSGIApp(self.branch, '').app)
+        app = TestApp(BranchWSGIApp(self.branch).app)
         return app
 
     def tearDown(self):

=== modified file 'loggerhead/util.py'
--- loggerhead/util.py	2008-09-10 00:07:49 +0000
+++ loggerhead/util.py	2008-08-06 21:25:24 +0000
@@ -32,9 +32,7 @@
 import struct
 import threading
 import time
-import sys
-import os
-import subprocess
+import types
 
 log = logging.getLogger("loggerhead.controllers")
 
@@ -344,71 +342,6 @@
             [navigation.scan_url, next_page_revno], **params)
 
 
-def directory_breadcrumbs(path, is_root, view):
-    """
-    Generate breadcrumb information from the directory path given
-
-    The path given should be a path up to any branch that is currently being
-    served
-
-    Arguments:
-    path -- The path to convert into breadcrumbs
-    is_root -- Whether or not loggerhead is serving a branch at its root
-    view -- The type of view we are showing (files, changes etc)
-    """
-    # Is our root directory itself a branch?
-    if is_root:
-        if view == 'directory':
-            directory = 'files'
-        breadcrumbs = [{
-            'dir_name': path,
-            'path': '',
-            'suffix': view,
-        }]
-    else:
-        # Create breadcrumb trail for the path leading up to the branch
-        breadcrumbs = [{
-            'dir_name': "(root)",
-            'path': '',
-            'suffix': '',
-        }]
-        if path != '/':
-            dir_parts = path.strip('/').split('/')
-            for index, dir_name in enumerate(dir_parts):
-                breadcrumbs.append({
-                    'dir_name': dir_name,
-                    'path': '/'.join(dir_parts[:index + 1]),
-                    'suffix': '',
-                })
-            # If we are not in the directory view, the last crumb is a branch,
-            # so we need to specify a view
-            if view != 'directory':
-                breadcrumbs[-1]['suffix'] = '/' + view
-    return breadcrumbs
-
-
-def branch_breadcrumbs(path, inv, view):
-    """
-    Generate breadcrumb information from the branch path given
-
-    The path given should be a path that exists within a branch
-
-    Arguments:
-    path -- The path to convert into breadcrumbs
-    inv -- Inventory to get file information from
-    view -- The type of view we are showing (files, changes etc)
-    """
-    dir_parts = path.strip('/').split('/')
-    inner_breadcrumbs = []
-    for index, dir_name in enumerate(dir_parts):
-        inner_breadcrumbs.append({
-            'dir_name': dir_name,
-            'file_id': inv.path2id('/'.join(dir_parts[:index + 1])),
-            'suffix': '/' + view ,
-        })
-    return inner_breadcrumbs
-
-
 def decorator(unbound):
     def new_decorator(f):
         g = unbound(f)
@@ -512,66 +445,3 @@
     overrides = dict((k, v) for (k, v) in overrides.iteritems() if k in _valid)
     map.update(overrides)
     return map
-
-
-class Reloader(object):
-    """
-    This class wraps all paste.reloader logic. All methods are @classmethod.
-    """
-
-    _reloader_environ_key = 'PYTHON_RELOADER_SHOULD_RUN'
-
-    @classmethod
-    def _turn_sigterm_into_systemexit(self):
-        """
-        Attempts to turn a SIGTERM exception into a SystemExit exception.
-        """
-        try:
-            import signal
-        except ImportError:
-            return
-        def handle_term(signo, frame):
-            raise SystemExit
-        signal.signal(signal.SIGTERM, handle_term)
-
-    @classmethod
-    def is_installed(self):
-        return os.environ.get(self._reloader_environ_key)
-    
-    @classmethod
-    def install(self):
-        from paste import reloader
-        reloader.install(int(1))
-    
-    @classmethod    
-    def restart_with_reloader(self):
-        """Based on restart_with_monitor from paste.script.serve."""
-        print 'Starting subprocess with file monitor'
-        while 1:
-            args = [sys.executable] + sys.argv
-            new_environ = os.environ.copy()
-            new_environ[self._reloader_environ_key] = 'true'
-            proc = None
-            try:
-                try:
-                    self._turn_sigterm_into_systemexit()
-                    proc = subprocess.Popen(args, env=new_environ)
-                    exit_code = proc.wait()
-                    proc = None
-                except KeyboardInterrupt:
-                    print '^C caught in monitor process'
-                    return 1
-            finally:
-                if (proc is not None
-                    and hasattr(os, 'kill')):
-                    import signal
-                    try:
-                        os.kill(proc.pid, signal.SIGTERM)
-                    except (OSError, IOError):
-                        pass
-                
-            # Reloader always exits with code 3; but if we are
-            # a monitor, any exit code will restart
-            if exit_code != 3:
-                return exit_code
-            print '-'*20, 'Restarting', '-'*20

=== modified file 'serve-branches'
--- serve-branches	2008-09-24 04:52:40 +0000
+++ serve-branches	2008-09-09 03:47:24 +0000
@@ -28,10 +28,8 @@
 from loggerhead import __version__
 from loggerhead.apps.filesystem import (
     BranchesFromFileSystemRoot, UserBranchesFromFileSystemRoot)
-from loggerhead.util import Reloader
 from loggerhead.apps.error import ErrorHandlerApp
 
-
 def command_line_parser():
     parser = OptionParser("%prog [options] <path>")
     parser.set_defaults(
@@ -43,19 +41,10 @@
                       help="Serve user directories as ~user.")
     parser.add_option("--trunk-dir", metavar="DIR",
                       help="The directory that contains the trunk branches.")
-    parser.add_option("--port", dest="user_port",
-                      help="Port Loggerhead should listen on (defaults to 8080).")
-    parser.add_option("--host", dest="user_host",
-                      help="Host Loggerhead should listen on.")
-    parser.add_option("--prefix", dest="user_prefix",
-                      help="Specify host prefix.")
-    parser.add_option("--reload", action="store_true", dest="reload",
-                      help="Restarts the application when changing python"
-                           " files. Only used for development purposes.")
-    parser.add_option('--log-folder', dest="log_folder",
-                      type=str, help="The directory to place log files in.")
     parser.add_option("--version", action="store_true", dest="show_version",
                       help="Print the software version and exit")
+    parser.add_option('--log-folder', dest="log_folder", 
+                      type=str, help="The directory to place log files")
     return parser
 
 
@@ -83,12 +72,6 @@
         print "--trunk-dir is only valid with --user-dirs"
         sys.exit(1)
 
-    if options.reload:
-        if Reloader.is_installed():
-            Reloader.install()
-        else:
-            return Reloader.restart_with_reloader()
-
     if options.user_dirs:
         if not options.trunk_dir:
             print "You didn't specify a directory for the trunk directories."
@@ -96,7 +79,7 @@
         app = UserBranchesFromFileSystemRoot(path, options.trunk_dir)
     else:
         app = BranchesFromFileSystemRoot(path)
-
+    
     # setup_logging()
     logging.basicConfig()
     logging.getLogger('').setLevel(logging.DEBUG)
@@ -116,29 +99,15 @@
     app = HTTPExceptionHandler(app)
     app = TransLogger(app, logger=logger)
 
-    if not options.user_prefix:
-        prefix = '/'
-    else:
-        prefix = options.user_prefix
 
     try:
         from paste.deploy.config import PrefixMiddleware
     except ImportError:
         pass
     else:
-        app = PrefixMiddleware(app, prefix=prefix)
-
-    if not options.user_port:
-        port = '8080'
-    else:
-        port = options.user_port
-
-    if not options.user_host:
-        host = '0.0.0.0'
-    else:
-        host = options.user_host
-
-    httpserver.serve(app, host=host, port=port)
+        app = PrefixMiddleware(app)
+
+    httpserver.serve(app, host='0.0.0.0', port='8080')
 
 
 if __name__ == "__main__":

=== modified file 'serve-branches.1'
--- serve-branches.1	2008-09-10 23:12:59 +0000
+++ serve-branches.1	2008-09-09 03:47:24 +0000
@@ -21,23 +21,11 @@
 \fB\-\-trunk\-dir\fR=\fIDIR\fR
 The directory that contains the trunk branches.
 .TP
-\fB\-\-port\fR
-Port Loggerhead should listen on (defaults to 8080).
-.TP
-\fB\-\-host\fR
-Host Loggerhead should listen on.
-.TP
-\fB\-\-prefix\fR
-Specify host prefix.
-.TP
-\fB\-\-reload\fR
-Restarts the application when changing python files. Only used for development purposes.
+\fB\-\-version\fR
+Print the software version and exit
 .TP
 \fB\-\-log\-folder\fR=\fILOG_FOLDER\fR
 The directory to place log files
-.TP
-\fB\-\-version\fR
-Print the software version and exit.
 .SH "LICENSE"
 GNU GPLv2 or later.
 .SH "SEE ALSO"

